@@ -80,6 +80,7 @@ class Model(Base):
     _FIELD_HISTOGRAM_MINIMUM = 'histogram_minimum'
     _FIELD_HISTOGRAM_MAXIMUM = 'histogram_maximum'
     _FIELD_ID = 'id'
+    _FIELD_INGESTERS = 'ingesters'
     _FIELD_INPUT = 'input'
     _FIELD_INPUTS = 'inputs'
     _FIELD_KEYWORDS = 'keywords'
@@ -88,6 +89,7 @@ class Model(Base):
     _FIELD_MINIMUM = 'minimum'
     _FIELD_NAME = 'name'
     _FIELD_NON_AGGREGATOR_COUNT = 'non_aggregator_count'
+    _FIELD_NUMBER_OF_INGESTERS = 'number_of_ingesters'
     _FIELD_OPTIONS = 'options'
     _FIELD_OUTPUTS = 'outputs'
     _FIELD_PROCESS_STATUS = 'process_status'
